Documentation
¶
Index ¶
- func BreakUpStringSlice(mediaFileIds []string, chunkSize int) [][]string
- func InsertString(array []string, value string, index int) []string
- func IntInSlice(a int, list []int) bool
- func IsAudioFile(filePath string) bool
- func IsDirReadable(path string) (bool, error)
- func IsImageFile(filePath string) bool
- func IsPlaylist(filePath string) bool
- func LongestCommonPrefix(list []string) string
- func MaxInt(x, y int) int
- func MinInt(x, y int) int
- func MoveString(array []string, srcIndex int, dstIndex int) []string
- func NewMergeFS(base, overlay http.FileSystem) http.FileSystem
- func NoArticle(name string) string
- func ParamBool(r *http.Request, param string, def bool) bool
- func ParamInt(r *http.Request, param string, def int) int
- func ParamInt64(r *http.Request, param string, def int64) int64
- func ParamInts(r *http.Request, param string) []int
- func ParamString(r *http.Request, param string) string
- func ParamStrings(r *http.Request, param string) []string
- func ParamTime(r *http.Request, param string, def time.Time) time.Time
- func ParamTimes(r *http.Request, param string) []time.Time
- func RemoveString(array []string, index int) []string
- func StringInSlice(a string, list []string) bool
- func ToMillis(t time.Time) int64
- func ToTime(millis int64) time.Time
- type AtomicBool
- type IndexGroups
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BreakUpStringSlice ¶ added in v0.23.0
func InsertString ¶ added in v0.22.0
func IntInSlice ¶
func IsAudioFile ¶ added in v0.24.0
func IsDirReadable ¶ added in v0.23.0
func IsImageFile ¶ added in v0.24.0
func IsPlaylist ¶ added in v0.26.0
func LongestCommonPrefix ¶
func MoveString ¶ added in v0.22.0
func NewMergeFS ¶ added in v0.27.0
func NewMergeFS(base, overlay http.FileSystem) http.FileSystem
NewMergeFS returns a simple implementation of a merged FS (http.FileSystem), that can combine a base FS with a overlay FS. The semantics are: - Files from the overlay FS will override file s with the same name in the base FS - Directories are combined, with priority for the overlay FS over the base FS for files with matching names
func RemoveString ¶ added in v0.22.0
func StringInSlice ¶
Types ¶
type AtomicBool ¶ added in v0.27.0
type AtomicBool struct {
// contains filtered or unexported fields
}
func (*AtomicBool) Get ¶ added in v0.27.0
func (b *AtomicBool) Get() bool
func (*AtomicBool) Set ¶ added in v0.27.0
func (b *AtomicBool) Set(value bool)
type IndexGroups ¶
func ParseIndexGroups ¶
func ParseIndexGroups(spec string) IndexGroups
The specification is a space-separated list of index entries. Normally, each entry is just a single character, but you may also specify multiple characters. For instance, the entry "The" will link to all files and folders starting with "The".
You may also create an entry using a group of index characters in parenthesis. For instance, the entry "A-E(ABCDE)" will display as "A-E" and link to all files and folders starting with either A, B, C, D or E. This may be useful for grouping less-frequently used characters (such and X, Y and Z), or for grouping accented characters (such as A, \u00C0 and \u00C1)
Files and folders that are not covered by an index entry will be placed under the index entry "#".