utils

package
v0.8.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 16, 2020 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IntInSlice

func IntInSlice(a int, list []int) bool

func LongestCommonPrefix

func LongestCommonPrefix(list []string) string

func MaxInt

func MaxInt(x, y int) int

func MinInt

func MinInt(x, y int) int

func NoArticle

func NoArticle(name string) string

func ParamBool added in v0.7.0

func ParamBool(r *http.Request, param string, def bool) bool

func ParamInt added in v0.7.0

func ParamInt(r *http.Request, param string, def int) int

func ParamInts added in v0.7.0

func ParamInts(r *http.Request, param string) []int

func ParamString added in v0.7.0

func ParamString(r *http.Request, param string) string

func ParamStrings added in v0.7.0

func ParamStrings(r *http.Request, param string) []string

func ParamTime added in v0.7.0

func ParamTime(r *http.Request, param string, def time.Time) time.Time

func ParamTimes added in v0.7.0

func ParamTimes(r *http.Request, param string) []time.Time

func StringInSlice

func StringInSlice(a string, list []string) bool

func ToMillis

func ToMillis(t time.Time) int64

func ToTime

func ToTime(millis int64) time.Time

Types

type IndexGroups

type IndexGroups map[string]string

func ParseIndexGroups

func ParseIndexGroups(spec string) IndexGroups

The specification is a space-separated list of index entries. Normally, each entry is just a single character, but you may also specify multiple characters. For instance, the entry "The" will link to all files and folders starting with "The".

You may also create an entry using a group of index characters in parenthesis. For instance, the entry "A-E(ABCDE)" will display as "A-E" and link to all files and folders starting with either A, B, C, D or E. This may be useful for grouping less-frequently used characters (such and X, Y and Z), or for grouping accented characters (such as A, \u00C0 and \u00C1)

Files and folders that are not covered by an index entry will be placed under the index entry "#".

Jump to