Documentation
¶
Index ¶
- func IntInSlice(a int, list []int) bool
- func LongestCommonPrefix(list []string) string
- func MaxInt(x, y int) int
- func MinInt(x, y int) int
- func NoArticle(name string) string
- func ParamBool(r *http.Request, param string, def bool) bool
- func ParamInt(r *http.Request, param string, def int) int
- func ParamInts(r *http.Request, param string) []int
- func ParamString(r *http.Request, param string) string
- func ParamStrings(r *http.Request, param string) []string
- func ParamTime(r *http.Request, param string, def time.Time) time.Time
- func ParamTimes(r *http.Request, param string) []time.Time
- func StringInSlice(a string, list []string) bool
- func ToMillis(t time.Time) int64
- func ToTime(millis int64) time.Time
- type IndexGroups
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IntInSlice ¶
func LongestCommonPrefix ¶
func StringInSlice ¶
Types ¶
type IndexGroups ¶
func ParseIndexGroups ¶
func ParseIndexGroups(spec string) IndexGroups
The specification is a space-separated list of index entries. Normally, each entry is just a single character, but you may also specify multiple characters. For instance, the entry "The" will link to all files and folders starting with "The".
You may also create an entry using a group of index characters in parenthesis. For instance, the entry "A-E(ABCDE)" will display as "A-E" and link to all files and folders starting with either A, B, C, D or E. This may be useful for grouping less-frequently used characters (such and X, Y and Z), or for grouping accented characters (such as A, \u00C0 and \u00C1)
Files and folders that are not covered by an index entry will be placed under the index entry "#".